diff --git a/Layout/default/Address/Index.php b/Layout/default/Address/Index.php
index c2d1376bb..5fb7a9824 100644
--- a/Layout/default/Address/Index.php
+++ b/Layout/default/Address/Index.php
@@ -39,10 +39,10 @@
diff --git a/Layout/default/Network/Form.php b/Layout/default/Network/Form.php
index d629d0c7a..242631406 100644
--- a/Layout/default/Network/Form.php
+++ b/Layout/default/Network/Form.php
@@ -52,7 +52,7 @@
+
+
+
@@ -93,11 +106,14 @@
\ No newline at end of file
diff --git a/application/Api/v1/Modules/Preorder/Cif.php b/application/Api/v1/Modules/Preorder/Cif.php
index e0e4ace06..cc54375aa 100644
--- a/application/Api/v1/Modules/Preorder/Cif.php
+++ b/application/Api/v1/Modules/Preorder/Cif.php
@@ -1,7 +1,7 @@
$this->get,
"post" => $this->post,
@@ -46,10 +49,12 @@ class PreorderApicontroller extends mfBaseApicontroller {
$this->addRoute("/preorder/customerInstallationFeedback", [$modules["Cif"], "getCifData"], "GET");
$this->addRoute("/preorder/customerInstallationFeedback", [$modules["Cif"], "userSetCif"], "POST");
- $this->addRoute("/preorder/:code", "getPreorder", "GET");
- $this->addRoute("/preorder/:code", "cancelPreorder", "DELETE");
$this->addRoute("/preorder/:code/clientInstallationFinished", [$modules["Cif"], "providerSetCif"], "GET");
$this->addRoute("/preorder/:code/serviceActivated", [$modules["Activation"], "setServiceActive"], "POST");
+ $this->addRoute("/preorder/:code", "getPreorder", "GET");
+ $this->addRoute("/preorder/:code", "cancelPreorder", "DELETE");
+
+
}
/*
diff --git a/application/Network/NetworkController.php b/application/Network/NetworkController.php
index 34e750194..b50cc00b6 100644
--- a/application/Network/NetworkController.php
+++ b/application/Network/NetworkController.php
@@ -75,6 +75,7 @@ class NetworkController extends mfBaseController {
$data['owner_id'] = $r->owner_id;
$data['name'] = $r->name;
$data['note'] = $r->note;
+ $data['adb_netzgebiet_id'] = $r->adb_netzgebiet_id;
if($r->sytemowner_action_status) {
$data['sytemowner_action_status'] = $r->sytemowner_action_status;
diff --git a/db/migrations/20231207133325_addressdb_netzgebiet_add_rimo_id.php b/db/migrations/20231207133325_addressdb_netzgebiet_add_rimo_id.php
new file mode 100644
index 000000000..c9340ff94
--- /dev/null
+++ b/db/migrations/20231207133325_addressdb_netzgebiet_add_rimo_id.php
@@ -0,0 +1,31 @@
+getEnvironment() == "thetool") {
+
+ }
+
+ if($this->getEnvironment() == "addressdb") {
+ $table = $this->table("Netzgebiet");
+ $table->addColumn("rimo_id", "string", ["null" => true, "default" => null, "limit" => 255, "after" => "extref"]);
+ $table->update();
+ }
+ }
+
+ public function down(): void
+ {
+ if($this->getEnvironment() == "thetool") {
+
+ }
+
+ if($this->getEnvironment() == "addressdb") {
+
+ }
+ }
+}
diff --git a/application/Api/v1/Modules/ApiControllerModule.php b/application/Api/v1/Modules/ApiControllerModule.php
index 6418ca2a5..7a29ee0dd 100644
--- a/application/Api/v1/Modules/ApiControllerModule.php
+++ b/application/Api/v1/Modules/ApiControllerModule.php
@@ -1,6 +1,6 @@
"Preorder not found"]);
@@ -41,9 +42,9 @@ class Activation extends Modules\ApiControllerModule {
return \mfResponse::NotFound(["message" => "Preorder not found"]);
}
- // set status to 200
- if($preorder->status->code < 200) {
- $new_status = \PreorderstatusModel::getFirst(["code" => 200]);
+ // set status to 500
+ if($preorder->status->code < 500) {
+ $new_status = \PreorderstatusModel::getFirst(["code" => 500]);
if(!$new_status) {
return \mfResponse::InternalServerError();
}